@@ -85,7 +85,7 @@ uchar SerialNum[MAX_PORTNUM][8];
 
 // external globals
 extern int UMode[MAX_PORTNUM];
-extern uchar USpeed[MAX_PORTNUM];
+extern SMALLINT USpeed[MAX_PORTNUM];
 
 //--------------------------------------------------------------------------
 // The 'owFirst' finds the first device on the 1-Wire Net  This function
